*******************************************************************************
/* 
PROJECT: SDN banking

OUTPUT OF THIS DO FILE:                                                   
- fig01
	
WRITTEN BY: Gregorio Impavido (gimpavido@imf.org)

WRITTEN WHEN:   02 Feb, 2013
*/
*******************************************************************************

*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/"
* on Q drive
* local base "//data2/EUR/DATA/UNIT/EE/Data/panelchart"
local dta "`base'"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"

*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

use "`wkdir'/wp-f01.dta", clear

drop if name20char=="Turkey" | name20char=="Russian Federation"

* merge and interpolate GDP
rename time timeq // this is the name for Q obs in the using dbase
merge 1:1 idifs timeq using "`wkdir'/wp-f01-macro.dta", keepusing(ngdpd) ///
	nogenerate
replace ngdpd = ngdpd*1000  // original data is in billion, now million
rename timeq time
ipolate ngdp time, by(idifs) gen(ngdpd_ipol)
label var ngdpd_ipol "GDP (USD Million, Linear Interpolation)"
drop ngdpd // we do not need the annual gdp

* build % of GDP
foreach var of varlist anx6a_usdass* anx6b_usdass* anx6c_usdass* {
	gen double gdp_`var' = 100*`var'/ngdpd_ipo
	local varlab `: variable label `var''
	local varlab1 `: di subinstr("`varlab'","USD Billion","%GDP",.)'
	label var gdp_`var' "`varlab1'"
	}

* Clean Names
drop if word(name20char,1)=="Yugoslavia,"
replace name20char="Macedonia" if word(name20char,1)=="Macedonia,"
replace name20char="Montenegro" if word(name20char,1)=="Montenegro,"
replace name20char="Russia" if word(name20char,1)=="Russian"
replace name20char="Slovak R." if word(name20char,1)=="Slovak"
replace name20char="Czech R." if word(name20char,1)=="Czech"
replace name20char="Serbia" if word(name20char,1)=="Serbia,"
replace name20char="BiH" if word(name20char,1)=="Bosnia"
replace name20char="UAE" if word(name20char,3)=="Emirates"
replace name20char="Bahrain" if word(name20char,1)=="Bahrain,"
replace name20char="Iran" if word(name20char,1)=="Iran,"
replace name20char="Trinidad" if word(name20char,1)=="Trinidad"
replace name20char="Dominican R." if word(name20char,1)=="Dominican"
replace name20char="Venezuela" if word(name20char,1)=="Venezuela,"
replace name20char="UK" if name20char=="United Kingdom"
replace name20char="Taiwan" if word(name20char,1)=="Taiwan"
replace name20char="Korea" if word(name20char,1)=="Korea,"
replace name20char="China" if name20char=="China,P.R.: Mainland"
replace name20char="Azerbaijan" if word(name20char,1)=="Azerbaijan,"
replace name20char="Afghanistan" if word(name20char,1)=="Afghanistan,"
replace name20char="Hong Kong" if name20char=="China,P.R.:Hong Kong"
replace name20char="Bahamas" if word(name20char,1)=="Bahamas,"
replace name20char="BWI" if name20char=="British West Indies"
replace name20char="Antilles (NLD)" if name20char=="Netherlands Antilles"
replace name20char="Cayman I." if word(name20char,1)=="Cayman"
replace name20char="USA" if name20char=="United States"

gen lac   = (reg=="Latin America/Caribbean":reg & ngdpd>20000)
gen asia  = (reg=="Asia & Pacific":reg & ngdpd>20000 & name20char!="Taiwan")


gen ep_cesee = 	gdp_anx6c_usdass_fx if cesee==1 & time==q(2008q2)
gen ep_lac   = 	gdp_anx6c_usdass_fx if lac==1 & time==q(2008q2) & gdp_anx6a_usdass_fx<.
gen ep_asia  = 	gdp_anx6c_usdass_fx if asia==1 & time==q(2008q2) & gdp_anx6a_usdass_fx<.

keep if time==q(2008q2)
preserve
import excel "`wkdir'/wp-f07-macro.xlsx", sheet("Sheet1") cellrange() firstrow clear
drop if idifs==.
save "`wkdir'/wp-f07-macro.dta", replace
restore
merge 1:1 idifs using "`wkdir'/wp-f07-macro.dta", keepusing(ass12usdbil ass08usdbil)
drop if _merge==1
drop _merge

foreach var of varlist ass12usdbil ass08usdbil  {
	replace `var' = `var'*1000  // original data is in billion, now million
}
	rename ass08usdbil ass08usdmil
	rename ass12usdbil ass12usdmil
	
gen a_anx6c_usdass_fx08 = gdp_anx6c_usdass_fx*ngdpd_ipo/ass08usdmil
gen a_anx6c_usdass_fx12 = gdp_anx6c_usdass_fx*ngdpd_ipo/ass12usdmil

gen ep_cesee_a08 = ep_cesee*ngdpd_ipo/ass08usdmil
gen ep_lac_a08 = ep_lac*ngdpd_ipo/ass08usdmil
gen ep_asia_a08 = ep_asia*ngdpd_ipo/ass08usdmil

gen ep_cesee_a12 = ep_cesee*ngdpd_ipo/ass12usdmil
gen ep_lac_a12 = ep_lac*ngdpd_ipo/ass12usdmil
gen ep_asia_a12 = ep_asia*ngdpd_ipo/ass12usdmil

outsheet name20char ep* using "`out'/wp-f02bis.txt" if ep_cesee<. | ep_lac<. | ep_asia<. , replace


quietly summ ep_cesee_a08 if time==q(2008q2)
local avcesee `: di %9.1fc r(mean)'
quietly summ ep_lac_a08 if time==q(2008q2)
local avlac `: di %9.1fc r(mean)'
quietly summ ep_asia_a08 if time==q(2008q2)
local avasia `: di %9.1fc r(mean)'


graph bar (asis) ep_cesee_a08 ep_lac_a08 ep_asia_a08 if ep_cesee_a08<. | ep_lac_a08<. | ep_asia_a08<., ///
over(name20char, sort(a_anx6c_usdass_fx08) descending label(labsize(vsmall) angle(45))) ///
nofill 																		///
bar(1, bstyle(p1bar))														///
bar(2, bstyle(p2bar))														///
bar(3, bstyle(p3bar))														///
/* blabel(bar, format(%2.0f) position(center) color(white) size(vsmall)) */	///
title("Figure 2. External Positions of BIS Banks Before the Crisis", span ring(7) position(11) size(*0.8)) 			///
subtitle("({it:2008q2 level as a percent of banking assets, vis-{c 224}-vis banks})", span ring(6) position(11) size(small)) 	///
ytitle(" ") 																///
ylabel(, format() ang(h) gstyle(major) glcolor(gs12))						///
text(45 80 "Av. CESEE: `avcesee'", placement(e) tstyle(smbody))				///
text(42 80 "Av. LAC: `avlac'", placement(e) tstyle(smbody))					///
text(39 80 "Av. Asia: `avasia'", placement(e) tstyle(smbody))				///
legend(order(1 2 3) label(1 "CESEE") label(2 "LAC") 							///
	label(3 "Asia") 														///
	cols() rows(1) size(vsmall) symxsize(vsmall) symysize(vsmall) 			///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) ///
note("Notes: External positions of BIS banks are vis-{c 224}-vis banks and FX adjusted. Averages are unweighted." 							///
"Sources: BIS International Statistics (Table 6), IMF WEO, IMF IFS, and authors' calculations.", size(vsmall) span)			///
graphregion(fcolor(ltbluishgray)) ysize() xsize() plotregion(style(none)) 
graph export "`out'/wp-f02bis.png", width(2500) replace
	
	
