*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/Loan Deposit"
local dta "`base'/dta"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"


*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"


*******************************************************************************
********************************* SCATTER GRAPHS ******************************
*******************************************************************************
use "`out'/wp-f12.dta", clear
outsheet using "`out'/wp-f12.txt", replace

drop if name=="Turkey" | name=="Russia"

* position of labels in scatter 
tempvar pos // This controls the positions of the mlabels
gen `pos' = 9
replace `pos' = 3 if  ddep>-bis
replace `pos' = 3 if name=="Albania"  // this controls individual points labels (add as needed)
replace `pos' = 4 if name=="Moldova"  // this controls individual points labels (add as needed)
replace `pos' = 2 if name=="Romania"  // this controls individual points labels (add as needed)
replace `pos' = 9 if name=="Czech R."  // this controls individual points labels (add as needed)

* graph
graph twoway 																///
(scatter ddep bis, msymbol() mcolor() msize(small) 			///
	 xaxis() mlabel(name) mlabvposition(`pos') mlabsize(vsmall) yline(0) xline(0))			///
(function y = -x , range(bis) color(black) yvarlabel("45{&ang} line")),		///
ytitle("Changes in Core Liabilities 1/")								///
ylabel(, format() ang(h) gstyle(major) glcolor(gs12))													///
xtitle("Changes in Non-Core Liabilities 2/") 					 					///
title("Figure 12. Changes in Core and Non-Core Liabilities During the Crisis",					///
	span position(11) size(*0.8)) /* play with size depending on length */	///
subtitle("({it:2008q2-2012q2, percent over GDP})",	span ring(6) position(11) size(small)) 		///
/* legend(order(1 2) label(1 "Consolidated Assets (USD million, bottom)") 	///
	label(2 "Subsidiary Share (%, top)") cols(2) rows (1)					///
	span bexpand symxsize(*0.7) size(*0.8) 									///
	region(fcolor(ltbluishgray))) */										///
legend(off)		 															///
text(-2 3 "45{&ang} line", place(e) size(vsmall))							///
note("Notes: 1/ Core Liabilities are given by FX adjusted deposits; 2/ Non-Core Liabilities are given by external positions of BIS reporting banks"		///
	"vis-{char 224}-vis domestic banks."	///
	"Sources: BIS, IFS, and authors' calculations.", size(vsmall) span)		///
caption("", ring(0) position(4) size(small) box) 							///
graphregion(fcolor()) ysize() plotregion(style(none))	
graph export "`out'/wp-f12.png", width(2500) replace

