*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/CESEE bank database/BScope2012"
local dta "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"


/*
* on Q drive
local base "//data2/EUR/DATA/UNIT/EE/Data/CESEE bank database/BScope2012"
local dta "`base'/dta"
local wkdir "O:\DATA\UNIT\EE\Papers\2012Q4 - banking in CESEE\SDN"
local out  "O:\DATA\UNIT\EE\Papers\2012Q4 - banking in CESEE\SDN"
*/

*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

import excel "`dta'/wp-t01.xlsx", sheet("Results") firstrow clear
rename BvDIDNumbers bvd_id
rename TotalAssetsthUSD2011 bvd_al12
rename Index bvd_idx
rename Countrycode bvd_ciso2
rename BankName bvd_name

* fix serbian banks which are actually in Kosovo
replace bvd_ciso2="KV" if City=="PRISTINA" | City=="PRISHTINA"
replace bvd_id = subinstr(bvd_id,"RS","KV",1)  if bvd_ciso2=="KV"

* keep one type of statement per bank (the largest asset)
gsort bvd_id -bvd_al12
by bvd_id : gen rank = _n
* by bvd_id : gen nsum = _N
keep if rank==1
drop rank

* gen rank of bank in total sector assets
sort bvd_ciso2 -bvd_al12
gsort bvd_ciso2  -bvd_al12
by bvd_ciso2 : egen double bvd_al12_tot = total(bvd_al12)	// total secter assets
gen double bsh = 100*bvd_al12/bvd_al12_tot
label var bsh "Bank Share in total sector assets"
by bvd_ciso2 : gen rank = _n
keep bvd_name bvd_ciso2 bvd_id bvd_al12 rank bsh
save "`out'/wp-t01.dta", replace

local dta "`base'/dta"
use "`dta'/bvds-guos-all.dta", clear

* prepare sample 
// keep only 2011 non missing data, GUOs that are bank, and ALL country GUOS
keep if guo_bank==1 & time==2011  & guo_al12<.  
/*
&  ///
 (inlist(guo_isr3,"AT","IT","FR","DE","BE","NL","SE","NO","FI") | ///
	inlist(guo_isr3,"US","ES","PT","IR","DK","GR","GB"))
*/

keep bvd_id guo_isr1 guo_isr3
merge 1:1 bvd_id using "`out'/wp-t01.dta"
drop if _merge==1

* generate GUO country names
gen guo_cname = guo_isr3
replace guo_cname ="Austria" if guo_cname=="AT"
replace guo_cname ="Belgium" if guo_cname=="BE"
replace guo_cname ="Bulgaria" if guo_cname=="BG"
replace guo_cname ="China" if guo_cname=="CN"
replace guo_cname ="Cyprus" if guo_cname=="CY"
replace guo_cname ="Germany" if guo_cname=="DE"
replace guo_cname ="Denmark" if guo_cname=="DK"
replace guo_cname ="Spain" if guo_cname=="ES"
replace guo_cname ="France" if guo_cname=="FR"
replace guo_cname ="UK" if guo_cname=="GB"
replace guo_cname ="Greece" if guo_cname=="GR"
replace guo_cname ="Hungary" if guo_cname=="HU"
replace guo_cname ="Israel" if guo_cname=="IL"
replace guo_cname ="Italy" if guo_cname=="IT"
replace guo_cname ="Korea" if guo_cname=="KR"
replace guo_cname ="Lebanon" if guo_cname=="LB"
replace guo_cname ="Latvia" if guo_cname=="LV"
replace guo_cname ="Netherlands" if guo_cname=="NL"
replace guo_cname ="Norway" if guo_cname=="NO"
replace guo_cname ="Poland" if guo_cname=="PL"
replace guo_cname ="Portugal" if guo_cname=="PT"
replace guo_cname ="Serbia" if guo_cname=="RS"
replace guo_cname ="Russia" if guo_cname=="RU"
replace guo_cname ="Sweden" if guo_cname=="SE"
replace guo_cname ="Slovenia" if guo_cname=="SI"
replace guo_cname ="Turkey" if guo_cname=="TR"
replace guo_cname ="UAE" if guo_cname=="UA"
replace guo_cname ="USA" if guo_cname=="US"


* generate BVD country names
gen bvd_cname = bvd_ciso2
replace bvd_cname ="Albania" if bvd_cname=="AL"
replace bvd_cname ="BiH" if bvd_cname=="BA"
replace bvd_cname ="Belarus" if bvd_cname=="BY"
replace bvd_cname ="Bulgaria" if bvd_cname=="BG"
replace bvd_cname ="Croatia" if bvd_cname=="HR"
replace bvd_cname ="Czech R." if bvd_cname=="CZ"
replace bvd_cname ="Estonia" if bvd_cname=="EE"
replace bvd_cname ="Hungary" if bvd_cname=="HU"
replace bvd_cname ="Kosovo" if bvd_cname=="KV"
replace bvd_cname ="Latvia" if bvd_cname=="LV"
replace bvd_cname ="Lithuania" if bvd_cname=="LT"
replace bvd_cname ="Macedonia" if bvd_cname=="MK"
replace bvd_cname ="Moldova" if bvd_cname=="MD"
replace bvd_cname ="Montenegro" if bvd_cname=="ME"
replace bvd_cname ="Poland" if bvd_cname=="PL"
replace bvd_cname ="Romania" if bvd_cname=="RO"
replace bvd_cname ="Russia" if bvd_cname=="RU"
replace bvd_cname ="Serbia" if bvd_cname=="RS"
replace bvd_cname ="Slovak R." if bvd_cname=="SK"
replace bvd_cname ="Slovenia" if bvd_cname=="SI"
replace bvd_cname ="Turkey" if bvd_cname=="TR"
replace bvd_cname ="Ukraine" if bvd_cname=="UA"

* generate short GUO bank names
gen guo_name = guo_isr1
replace guo_name = "Citigroup" if guo_isr1=="Citigroup Inc"
replace guo_name = "Swedbank" if guo_isr1=="Swedbank AB"
replace guo_name = "SEB" if guo_isr1=="Skandinaviska Enskilda Banken AB"
replace guo_name = "Nordea" if guo_isr1=="Nordea Bank AB (publ)"
replace guo_name = "Home Credit" if guo_isr1=="Home Credit BV"
replace guo_name = "ING" if guo_isr1=="ING Bank NV"
replace guo_name = "FGA Capital" if guo_isr1=="FGA Capital SPA"
replace guo_name = "Banco Veneto" if guo_isr1=="Veneto Banca scpa"
replace guo_name = "Banco Popolare" if guo_isr1=="Banco Popolare"
replace guo_name = "Intesa Sanpaolo" if guo_isr1=="Intesa Sanpaolo"
replace guo_name = "UniCredit" if guo_isr1=="UniCredit SpA"
replace guo_name = "RCI" if guo_isr1=="RCI Banque"
replace guo_name = "Socit Gnrale" if guo_isr1=="Socit Gnrale"
replace guo_name = "Crdit Agricole" if guo_isr1=="Crdit Agricole S.A."
replace guo_name = "BNP" if guo_isr1=="BNP Paribas"
replace guo_name = "BBVA" if guo_isr1=="Banco Bilbao Vizcaya Argentaria SA"
replace guo_name = "Santander" if guo_isr1=="Banco Santander SA"
replace guo_name = "ProCredit" if guo_isr1=="ProCredit Holding AG"
replace guo_name = "Wstenrot" if guo_isr1=="Wstenrot & Wrttembergische"
replace guo_name = "Bayerische" if guo_isr1=="Bayerische Landesbank"
replace guo_name = "DZ Bank" if guo_isr1=="DZ Bank AG-Deutsche Zentral-Genossenschaftsbank"
replace guo_name = "Commerzbank" if guo_isr1=="Commerzbank AG"
replace guo_name = "Deutsche Bank" if guo_isr1=="Deutsche Bank AG"
replace guo_name = "KBC" if guo_isr1=="KBC Bank NV"
replace guo_name = "Bank Styria" if guo_isr1=="Steiermrkische Bank und Sparkassen AG-Bank Styria"
replace guo_name = "Hypo Alpe-Adria" if guo_isr1=="Hypo Alpe-Adria Bank International AG-Hypo Alpe-Adria-Group"
replace guo_name = "BAWAG PSK" if substr(guo_isr1,1,8)=="Bank fr"
replace guo_name = "Volksbank" if guo_isr1=="Volksbanken Holding regGenmbH"
replace guo_name = "Raiffeisen - RZB" if guo_isr1=="Raiffeisen Zentralbank Oesterreich AG - RZB"
replace guo_name = "Erste" if guo_isr1=="Erste Group Bank AG"
replace guo_name = "BKS" if guo_isr1=="BKS Bank AG"
replace guo_name = "Kaerntner" if guo_isr1=="Kaerntner Sparkasse"
replace guo_name = "BCP" if substr(guo_isr1,1,21)=="Banco Comercial Portu"
replace guo_name = "Hypo-Bank Burgenland" if substr(guo_isr1,1,15)=="Hypo-Bank Burge"
replace guo_name = "Warburg" if guo_isr1=="M.M. Warburg & CO Gruppe KGaA"
replace guo_name = "NBG" if guo_isr1=="National Bank of Greece SA"
replace guo_name = "Rabobank" if guo_isr1=="Rabobank Nederland-Rabobank Group"
replace guo_name = "RBS" if guo_isr1=="Royal Bank of Scotland Group Plc (The)"
replace guo_name = "Goldman Sachs" if substr(guo_isr1,1,13)=="Goldman Sachs"
replace guo_name = "Eurobank Ergasias" if substr(guo_isr1,1,17)=="Eurobank Ergasias"
replace guo_name = "Piraeus Bank" if substr(guo_isr1,1,12)=="Piraeus Bank"
replace guo_name = "Alpha Bank" if substr(guo_isr1,1,10)=="Alpha Bank"
replace guo_name = "HSBC" if substr(guo_isr1,1,4)=="HSBC"
replace guo_name = "NLB" if substr(guo_isr1,1,3)=="NLB"
replace guo_name = "OTP" if substr(guo_isr1,1,3)=="OTP"

* generate short BVD bank names
 replace bvd_name = "AB DNB Bankas" if bvd_name=="AB DNB Bankas"
 replace bvd_name = "AB SEB Bankas" if bvd_name=="AB SEB Bankas"
 replace bvd_name = "DNB SocGen" if bvd_name=="BRD-Groupe Societe Generale SA"
 replace bvd_name = "BRE Bank" if bvd_name=="BRE Bank SA"
 replace bvd_name = "Banca Comerciala Romana" if bvd_name=="Banca Comerciala Romana SA-Romanian Commercial Bank SA"
 replace bvd_name = "Banca Intesa ad Beograd" if bvd_name=="Banca Intesa ad Beograd"
 replace bvd_name = "Bank Polska Kasa Opieki" if bvd_name=="Bank Polska Kasa Opieki SA-Bank Pekao SA"
 replace bvd_name = "Ceska Sporitelna" if bvd_name=="Ceska Sporitelna a.s."
 replace bvd_name = "CSO" if bvd_name=="Ceskoslovenska Obchodni Banka A.S.- CSOB"
 replace bvd_name = "Crnogorsko" if bvd_name=="Crnogorsko Komercijalna Banka AD Podgorica-CKB Bank"
 replace bvd_name = "DSK Bank" if bvd_name=="DSK Bank Plc"
 replace bvd_name = "Erste & Steiermrkische Bank" if bvd_name=="Erste & Steiermrkische Bank dd"
 replace bvd_name = "Erste Bank" if bvd_name=="Erste Bank Hungary Nyrt"
 replace bvd_name = "Hypo Alpe-Adria-Bank" if bvd_name=="Hypo Alpe-Adria-Bank a.d. Banja Luka"
 replace bvd_name = "Intesa Sanpaolo" if bvd_name=="Intesa Sanpaolo Bank Albania"
 replace bvd_name = "Komercni Banka" if bvd_name=="Komercni Banka"
 replace bvd_name = "MKB Bank" if bvd_name=="MKB Bank Zrt"
 replace bvd_name = "NLB Tutunska Banka" if bvd_name=="NLB Tutunska Banka A.D. Skopje"
 replace bvd_name = "Privredna Banka Zagreb" if bvd_name=="Privredna Banka Zagreb d.d-Privredna Banka Zagreb Group"
 replace bvd_name = "Raiffeisen Bank Albania" if bvd_name=="Raiffeisen Bank Albania"
 replace bvd_name = "Raiffeisen Bank Aval" if bvd_name=="Raiffeisen Bank Aval"
 replace bvd_name = "Raiffeisen Bank Bosnia" if bvd_name=="Raiffeisenbank d.d. Bosnia and Herzegovina"
 replace bvd_name = "SEB" if bvd_name=="SEB Pank"
 replace bvd_name = "SEB" if bvd_name=="SEB banka AS"
 replace bvd_name = "Slovenska Sporitelna" if bvd_name=="Slovenska sporitel'na as-Slovak Savings Bank"
 replace bvd_name = "SocGen Montenegro" if bvd_name=="Societe Generale Banka Montenegro AD"
 replace bvd_name = "Stopanska Banka" if bvd_name=="Stopanska Banka a.d. Skopje"
 replace bvd_name = "SwedBank" if bvd_name=="Swedbank AB"
 replace bvd_name = "SwedBank" if bvd_name=="Swedbank AS"
 replace bvd_name = "SwedBank" if bvd_name=="Swedbank As"
 replace bvd_name = "Tatra Banka" if bvd_name=="Tatra Banka a.s."
 replace bvd_name = "UniCredit" if bvd_name=="UniCredit Bank Serbia JSC-UniCredit Bank Srbija a.d"
 replace bvd_name = "UniCredit" if bvd_name=="UniCredit Bank dd"
 replace bvd_name = "UniCredit" if bvd_name=="UniCredit Bulbank AD"
 replace bvd_name = "UBB" if bvd_name=="United Bulgarian Bank - UBB"
 replace bvd_name = "Vseobecna Uverova Bank" if bvd_name=="Vseobecna Uverova Banka a.s."
 replace bvd_name = "Zagrebacka Bank" if bvd_name=="Zagrebacka Banka dd"


drop if substr(bvd_id,1,2)=="RU"  // restrict to EE countries
drop if substr(bvd_id,1,2)=="TR"  // restrict to EE countries

gsort bvd_cname rank
edit bvd_cname bvd_name bsh rank guo_cname guo_name if rank<=3 & guo_name!=""
outsheet bvd_cname bvd_name bsh rank guo_cname guo_name using "`out'/wp-t01.txt" if rank<=3 & guo_name!="", replace
